countries = [
    {
        "timezones": ["Africa/Abidjan"],
        "code": "CI",
        "continent": "Africa",
        "name": "C\xc3\xb4te d'Ivoire",
        "capital": "Yamoussoukro",
    },
    {
        "timezones": ["Africa/Accra"],
        "code": "GH",
        "continent": "Africa",
        "name": "Ghana",
        "capital": "Accra",
    },
    {
        "timezones": ["Africa/Addis_Ababa"],
        "code": "ET",
        "continent": "Africa",
        "name": "Ethiopia",
        "capital": "Addis Ababa",
    },
    {
        "timezones": ["Africa/Algiers"],
        "code": "DZ",
        "continent": "Africa",
        "name": "Algeria",
        "capital": "Algiers",
    },
    {
        "timezones": ["Africa/Asmera"],
        "code": "ER",
        "continent": "Africa",
        "name": "Eritrea",
        "capital": "Asmara",
    },
    {
        "timezones": ["Africa/Bamako"],
        "code": "ML",
        "continent": "Africa",
        "name": "Mali",
        "capital": "Bamako",
    },
    {
        "timezones": ["Africa/Bangui"],
        "code": "CF",
        "continent": "Africa",
        "name": "Central African Republic",
        "capital": "Bangui",
    },
    {
        "timezones": ["Africa/Banjul"],
        "code": "GM",
        "continent": "Africa",
        "name": "The Gambia",
        "capital": "Banjul",
    },
    {
        "timezones": ["Africa/Bissau"],
        "code": "GW",
        "continent": "Africa",
        "name": "Guinea-Bissau",
        "capital": "Bissau",
    },
    {
        "timezones": ["Africa/Blantyre"],
        "code": "MW",
        "continent": "Africa",
        "name": "Malawi",
        "capital": "Lilongwe",
    },
    {
        "timezones": ["Africa/Brazzaville"],
        "code": "CG",
        "continent": "Africa",
        "name": "Republic of the Congo",
        "capital": "Brazzaville",
    },
    {
        "timezones": ["Africa/Bujumbura"],
        "code": "BI",
        "continent": "Africa",
        "name": "Burundi",
        "capital": "Bujumbura",
    },
    {
        "timezones": ["Africa/Cairo"],
        "code": "EG",
        "continent": "Africa",
        "name": "Egypt",
        "capital": "Cairo",
    },
    {
        "timezones": ["Africa/Casablanca"],
        "code": "MA",
        "continent": "Africa",
        "name": "Morocco",
        "capital": "Rabat",
    },
    {
        "timezones": ["Africa/Conakry"],
        "code": "GN",
        "continent": "Africa",
        "name": "Guinea",
        "capital": "Conakry",
    },
    {
        "timezones": ["Africa/Dakar"],
        "code": "SN",
        "continent": "Africa",
        "name": "Senegal",
        "capital": "Dakar",
    },
    {
        "timezones": ["Africa/Dar_es_Salaam"],
        "code": "TZ",
        "continent": "Africa",
        "name": "Tanzania",
        "capital": "Dodoma",
    },
    {
        "timezones": ["Africa/Djibouti"],
        "code": "DJ",
        "continent": "Africa",
        "name": "Djibouti",
        "capital": "Djibouti City",
    },
    {
        "timezones": ["Africa/Douala"],
        "code": "CM",
        "continent": "Africa",
        "name": "Cameroon",
        "capital": "Yaound\xc3\xa9",
    },
    {
        "timezones": ["Africa/Freetown"],
        "code": "SL",
        "continent": "Africa",
        "name": "Sierra Leone",
        "capital": "Freetown",
    },
    {
        "timezones": ["Africa/Gaborone"],
        "code": "BW",
        "continent": "Africa",
        "name": "Botswana",
        "capital": "Gaborone",
    },
    {
        "timezones": ["Africa/Harare"],
        "code": "ZW",
        "continent": "Africa",
        "name": "Zimbabwe",
        "capital": "Harare",
    },
    {
        "timezones": ["Africa/Johannesburg"],
        "code": "ZA",
        "continent": "Africa",
        "name": "South Africa",
        "capital": "Pretoria",
    },
    {
        "timezones": ["Africa/Kampala"],
        "code": "UG",
        "continent": "Africa",
        "name": "Uganda",
        "capital": "Kampala",
    },
    {
        "timezones": ["Africa/Khartoum"],
        "code": "SD",
        "continent": "Africa",
        "name": "Sudan",
        "capital": "Khartoum",
    },
    {
        "timezones": ["Africa/Kigali"],
        "code": "RW",
        "continent": "Africa",
        "name": "Rwanda",
        "capital": "Kigali",
    },
    {
        "timezones": ["Africa/Kinshasa", "Africa/Lubumbashi"],
        "code": "CD",
        "continent": "Africa",
        "name": "Democratic Republic of the Congo",
        "capital": "Kinshasa",
    },
    {
        "timezones": ["Africa/Lagos"],
        "code": "NG",
        "continent": "Africa",
        "name": "Nigeria",
        "capital": "Abuja",
    },
    {
        "timezones": ["Africa/Libreville"],
        "code": "GA",
        "continent": "Africa",
        "name": "Gabon",
        "capital": "Libreville",
    },
    {
        "timezones": ["Africa/Lome"],
        "code": "TG",
        "continent": "Africa",
        "name": "Togo",
        "capital": "Lom\xc3\xa9",
    },
    {
        "timezones": ["Africa/Luanda"],
        "code": "AO",
        "continent": "Africa",
        "name": "Angola",
        "capital": "Luanda",
    },
    {
        "timezones": ["Africa/Lusaka"],
        "code": "ZM",
        "continent": "Africa",
        "name": "Zambia",
        "capital": "Lusaka",
    },
    {
        "timezones": ["Africa/Malabo"],
        "code": "GQ",
        "continent": "Africa",
        "name": "Equatorial Guinea",
        "capital": "Malabo",
    },
    {
        "timezones": ["Africa/Maputo"],
        "code": "MZ",
        "continent": "Africa",
        "name": "Mozambique",
        "capital": "Maputo",
    },
    {
        "timezones": ["Africa/Maseru"],
        "code": "LS",
        "continent": "Africa",
        "name": "Lesotho",
        "capital": "Maseru",
    },
    {
        "timezones": ["Africa/Mbabane"],
        "code": "SZ",
        "continent": "Africa",
        "name": "Swaziland",
        "capital": "Mbabane",
    },
    {
        "timezones": ["Africa/Mogadishu"],
        "code": "SO",
        "continent": "Africa",
        "name": "Somalia",
        "capital": "Mogadishu",
    },
    {
        "timezones": ["Africa/Monrovia"],
        "code": "LR",
        "continent": "Africa",
        "name": "Liberia",
        "capital": "Monrovia",
    },
    {
        "timezones": ["Africa/Nairobi"],
        "code": "KE",
        "continent": "Africa",
        "name": "Kenya",
        "capital": "Nairobi",
    },
    {
        "timezones": ["Africa/Ndjamena"],
        "code": "TD",
        "continent": "Africa",
        "name": "Chad",
        "capital": "N'Djamena",
    },
    {
        "timezones": ["Africa/Niamey"],
        "code": "NE",
        "continent": "Africa",
        "name": "Niger",
        "capital": "Niamey",
    },
    {
        "timezones": ["Africa/Nouakchott"],
        "code": "MR",
        "continent": "Africa",
        "name": "Mauritania",
        "capital": "Nouakchott",
    },
    {
        "timezones": ["Africa/Ouagadougou"],
        "code": "BF",
        "continent": "Africa",
        "name": "Burkina Faso",
        "capital": "Ouagadougou",
    },
    {
        "timezones": ["Africa/Porto-Novo"],
        "code": "BJ",
        "continent": "Africa",
        "name": "Benin",
        "capital": "Porto-Novo",
    },
    {
        "timezones": ["Africa/Sao_Tome"],
        "code": "ST",
        "continent": "Africa",
        "name": "S\xc3\xa3o Tom\xc3\xa9 and Pr\xc3\xadncipe",
        "capital": "S\xc3\xa3o Tom\xc3\xa9",
    },
    {
        "timezones": ["Africa/Tripoli"],
        "code": "LY",
        "continent": "Africa",
        "name": "Libya",
        "capital": "Tripoli",
    },
    {
        "timezones": ["Africa/Tunis"],
        "code": "TN",
        "continent": "Africa",
        "name": "Tunisia",
        "capital": "Tunis",
    },
    {
        "timezones": ["Africa/Windhoek"],
        "code": "NA",
        "continent": "Africa",
        "name": "Namibia",
        "capital": "Windhoek",
    },
    {
        "timezones": ["America/Antigua"],
        "code": "AG",
        "continent": "North America",
        "name": "Antigua and Barbuda",
        "capital": "St. John's",
    },
    {
        "timezones": [
            "America/Argentina/Buenos_Aires",
            "America/Argentina/Cordoba",
            "America/Argentina/Jujuy",
            "America/Argentina/Tucuman",
            "America/Argentina/Catamarca",
            "America/Argentina/La_Rioja",
            "America/Argentina/San_Juan",
            "America/Argentina/Mendoza",
            "America/Argentina/Rio_Gallegos",
            "America/Argentina/Ushuaia",
        ],
        "code": "AR",
        "continent": "South America",
        "name": "Argentina",
        "capital": "Buenos Aires",
    },
    {
        "timezones": ["America/Asuncion"],
        "code": "PY",
        "continent": "South America",
        "name": "Paraguay",
        "capital": "Asunci\xc3\xb3n",
    },
    {
        "timezones": ["America/Barbados"],
        "code": "BB",
        "continent": "North America",
        "name": "Barbados",
        "capital": "Bridgetown",
    },
    {
        "timezones": ["America/Belize"],
        "code": "BZ",
        "continent": "North America",
        "name": "Belize",
        "capital": "Belmopan",
    },
    {
        "timezones": ["America/Bogota"],
        "code": "CO",
        "continent": "South America",
        "name": "Colombia",
        "capital": "Bogot\xc3\xa1",
    },
    {
        "timezones": ["America/Caracas"],
        "code": "VE",
        "continent": "South America",
        "name": "Venezuela",
        "capital": "Caracas",
    },
    {
        "timezones": ["America/Costa_Rica"],
        "code": "CR",
        "continent": "North America",
        "name": "Costa Rica",
        "capital": "San Jos\xc3\xa9",
    },
    {
        "timezones": ["America/Dominica"],
        "code": "DM",
        "continent": "North America",
        "name": "Dominica",
        "capital": "Roseau",
    },
    {
        "timezones": ["America/El_Salvador"],
        "code": "SV",
        "continent": "North America",
        "name": "El Salvador",
        "capital": "San Salvador",
    },
    {
        "timezones": ["America/Grenada"],
        "code": "GD",
        "continent": "North America",
        "name": "Grenada",
        "capital": "St. George's",
    },
    {
        "timezones": ["America/Guatemala"],
        "code": "GT",
        "continent": "North America",
        "name": "Guatemala",
        "capital": "Guatemala City",
    },
    {
        "timezones": ["America/Guatemala"],
        "code": "GT",
        "continent": "North America",
        "name": "Haiti",
        "capital": "Port-au-Prince",
    },
    {
        "timezones": ["America/Guayaquil", "Pacific/Galapagos"],
        "code": "EC",
        "continent": "South America",
        "name": "Ecuador",
        "capital": "Quito",
    },
    {
        "timezones": ["America/Guyana"],
        "code": "GY",
        "continent": "South America",
        "name": "Guyana",
        "capital": "Georgetown",
    },
    {
        "timezones": ["America/Havana"],
        "code": "CU",
        "continent": "North America",
        "name": "Cuba",
        "capital": "Havana",
    },
    {
        "timezones": ["America/Jamaica"],
        "code": "JM",
        "continent": "North America",
        "name": "Jamaica",
        "capital": "Kingston",
    },
    {
        "timezones": ["America/La_Paz"],
        "code": "BO",
        "continent": "South America",
        "name": "Bolivia",
        "capital": "Sucre",
    },
    {
        "timezones": ["America/Lima"],
        "code": "PE",
        "continent": "South America",
        "name": "Peru",
        "capital": "Lima",
    },
    {
        "timezones": ["America/Managua"],
        "code": "NI",
        "continent": "North America",
        "name": "Nicaragua",
        "capital": "Managua",
    },
    {
        "timezones": [
            "America/Mexico_City",
            "America/Cancun",
            "America/Merida",
            "America/Monterrey",
            "America/Mazatlan",
            "America/Chihuahua",
            "America/Hermosillo",
            "America/Tijuana",
        ],
        "code": "MX",
        "continent": "North America",
        "name": "Mexico",
        "capital": "Mexico City",
    },
    {
        "timezones": ["America/Montevideo"],
        "code": "UY",
        "continent": "South America",
        "name": "Uruguay",
        "capital": "Montevideo",
    },
    {
        "timezones": ["America/Nassau"],
        "code": "BS",
        "continent": "North America",
        "name": "Bahamas",
        "capital": "Nassau",
    },
    {
        "timezones": [
            "America/New_York",
            "America/Detroit",
            "America/Kentucky/Louisville",
            "America/Kentucky/Monticello",
            "America/Indiana/Indianapolis",
            "America/Indiana/Marengo",
            "America/Indiana/Knox",
            "America/Indiana/Vevay",
            "America/Chicago",
            "America/Indiana/Vincennes",
            "America/Indiana/Petersburg",
            "America/Menominee",
            "America/North_Dakota/Center",
            "America/North_Dakota/New_Salem",
            "America/Denver",
            "America/Boise",
            "America/Shiprock",
            "America/Phoenix",
            "America/Los_Angeles",
            "America/Anchorage",
            "America/Juneau",
            "America/Yakutat",
            "America/Nome",
            "America/Adak",
            "Pacific/Honolulu",
        ],
        "code": "US",
        "continent": "North America",
        "name": "United States",
        "capital": "Washington, D.C.",
    },
    {
        "timezones": [
            "America/Noronha",
            "America/Belem",
            "America/Fortaleza",
            "America/Recife",
            "America/Araguaina",
            "America/Maceio",
            "America/Bahia",
            "America/Sao_Paulo",
            "America/Campo_Grande",
            "America/Cuiaba",
            "America/Porto_Velho",
            "America/Boa_Vista",
            "America/Manaus",
            "America/Eirunepe",
            "America/Rio_Branco",
        ],
        "code": "BR",
        "continent": "South America",
        "name": "Brazil",
        "capital": "Bras\xc3\xadlia",
    },
    {
        "timezones": ["America/Panama"],
        "code": "PA",
        "continent": "North America",
        "name": "Panama",
        "capital": "Panama City",
    },
    {
        "timezones": ["America/Paramaribo"],
        "code": "SR",
        "continent": "South America",
        "name": "Suriname",
        "capital": "Paramaribo",
    },
    {
        "timezones": ["America/Port_of_Spain"],
        "code": "TT",
        "continent": "North America",
        "name": "Trinidad and Tobago",
        "capital": "Port of Spain",
    },
    {
        "timezones": ["America/Santiago", "Pacific/Easter"],
        "code": "CL",
        "continent": "South America",
        "name": "Chile",
        "capital": "Santiago",
    },
    {
        "timezones": ["America/Santo_Domingo"],
        "code": "DO",
        "continent": "North America",
        "name": "Dominican Republic",
        "capital": "Santo Domingo",
    },
    {
        "timezones": [
            "America/St_Johns",
            "America/Halifax",
            "America/Glace_Bay",
            "America/Moncton",
            "America/Goose_Bay",
            "America/Blanc-Sablon",
            "America/Montreal",
            "America/Toronto",
            "America/Nipigon",
            "America/Thunder_Bay",
            "America/Pangnirtung",
            "America/Iqaluit",
            "America/Atikokan",
            "America/Rankin_Inlet",
            "America/Winnipeg",
            "America/Rainy_River",
            "America/Cambridge_Bay",
            "America/Regina",
            "America/Swift_Current",
            "America/Edmonton",
            "America/Yellowknife",
            "America/Inuvik",
            "America/Dawson_Creek",
            "America/Vancouver",
            "America/Whitehorse",
            "America/Dawson",
        ],
        "code": "CA",
        "continent": "North America",
        "name": "Canada",
        "capital": "Ottawa",
    },
    {
        "timezones": ["America/St_Kitts"],
        "code": "KN",
        "continent": "North America",
        "name": "Saint Kitts and Nevis",
        "capital": "Basseterre",
    },
    {
        "timezones": ["America/St_Lucia"],
        "code": "LC",
        "continent": "North America",
        "name": "Saint Lucia",
        "capital": "Castries",
    },
    {
        "timezones": ["America/St_Vincent"],
        "code": "VC",
        "continent": "North America",
        "name": "Saint Vincent and the Grenadines",
        "capital": "Kingstown",
    },
    {
        "timezones": ["America/Tegucigalpa"],
        "code": "HN",
        "continent": "North America",
        "name": "Honduras",
        "capital": "Tegucigalpa",
    },
    {
        "timezones": ["Asia/Aden"],
        "code": "YE",
        "continent": "Asia",
        "name": "Yemen",
        "capital": "Sana'a",
    },
    {
        "timezones": [
            "Asia/Almaty",
            "Asia/Qyzylorda",
            "Asia/Aqtobe",
            "Asia/Aqtau",
            "Asia/Oral",
        ],
        "code": "KZ",
        "continent": "Asia",
        "name": "Kazakhstan",
        "capital": "Astana",
    },
    {
        "timezones": ["Asia/Amman"],
        "code": "JO",
        "continent": "Asia",
        "name": "Jordan",
        "capital": "Amman",
    },
    {
        "timezones": ["Asia/Ashgabat"],
        "code": "TM",
        "continent": "Asia",
        "name": "Turkmenistan",
        "capital": "Ashgabat",
    },
    {
        "timezones": ["Asia/Baghdad"],
        "code": "IQ",
        "continent": "Asia",
        "name": "Iraq",
        "capital": "Baghdad",
    },
    {
        "timezones": ["Asia/Bahrain"],
        "code": "BH",
        "continent": "Asia",
        "name": "Bahrain",
        "capital": "Manama",
    },
    {
        "timezones": ["Asia/Baku"],
        "code": "AZ",
        "continent": "Asia",
        "name": "Azerbaijan",
        "capital": "Baku",
    },
    {
        "timezones": ["Asia/Bangkok"],
        "code": "TH",
        "continent": "Asia",
        "name": "Thailand",
        "capital": "Bangkok",
    },
    {
        "timezones": ["Asia/Beirut"],
        "code": "LB",
        "continent": "Asia",
        "name": "Lebanon",
        "capital": "Beirut",
    },
    {
        "timezones": ["Asia/Bishkek"],
        "code": "KG",
        "continent": "Asia",
        "name": "Kyrgyzstan",
        "capital": "Bishkek",
    },
    {
        "timezones": ["Asia/Brunei"],
        "code": "BN",
        "continent": "Asia",
        "name": "Brunei Darussalam",
        "capital": "Bandar Seri Begawan",
    },
    {
        "timezones": ["Asia/Calcutta"],
        "code": "IN",
        "continent": "Asia",
        "name": "India",
        "capital": "New Delhi",
    },
    {
        "timezones": ["Asia/Colombo"],
        "code": "LK",
        "continent": "Asia",
        "name": "Sri Lanka",
        "capital": "Sri Jayewardenepura Kotte",
    },
    {
        "timezones": ["Asia/Damascus"],
        "code": "SY",
        "continent": "Asia",
        "name": "Syria",
        "capital": "Damascus",
    },
    {
        "timezones": ["Asia/Dhaka"],
        "code": "BD",
        "continent": "Asia",
        "name": "Bangladesh",
        "capital": "Dhaka",
    },
    {
        "timezones": ["Asia/Dili"],
        "code": "TL",
        "continent": "Asia",
        "name": "East Timor",
        "capital": "Dili",
    },
    {
        "timezones": ["Asia/Dubai"],
        "code": "AE",
        "continent": "Asia",
        "name": "United Arab Emirates",
        "capital": "Abu Dhabi",
    },
    {
        "timezones": ["Asia/Dushanbe"],
        "code": "TJ",
        "continent": "Asia",
        "name": "Tajikistan",
        "capital": "Dushanbe",
    },
    {
        "timezones": ["Asia/Hong_Kong"],
        "code": "HKG",
        "continent": "Asia",
        "name": "Hong Kong",
        "capital": "Hong Kong",
    },
    {
        "timezones": [
            "Asia/Jakarta",
            "Asia/Pontianak",
            "Asia/Makassar",
            "Asia/Jayapura",
        ],
        "code": "ID",
        "continent": "Asia",
        "name": "Indonesia",
        "capital": "Jakarta",
    },
    {
        "timezones": ["Asia/Jerusalem"],
        "code": "IL",
        "continent": "Asia",
        "name": "Israel",
        "capital": "Jerusalem",
    },
    {
        "timezones": ["Asia/Kabul"],
        "code": "AF",
        "continent": "Asia",
        "name": "Afghanistan",
        "capital": "Kabul",
    },
    {
        "timezones": ["Asia/Kabul"],
        "code": "AF",
        "continent": "Asia",
        "name": "Afghanistan",
        "capital": "Kabul",
    },
    {
        "timezones": ["Asia/Karachi"],
        "code": "PK",
        "continent": "Asia",
        "name": "Pakistan",
        "capital": "Islamabad",
    },
    {
        "timezones": ["Asia/Katmandu"],
        "code": "NP",
        "continent": "Asia",
        "name": "Nepal",
        "capital": "Kathmandu",
    },
    {
        "timezones": ["Asia/Kuala_Lumpur", "Asia/Kuching"],
        "code": "MY",
        "continent": "Asia",
        "name": "Malaysia",
        "capital": "Kuala Lumpur",
    },
    {
        "timezones": ["Asia/Kuwait"],
        "code": "KW",
        "continent": "Asia",
        "name": "Kuwait",
        "capital": "Kuwait City",
    },
    {
        "timezones": ["Asia/Manila"],
        "code": "PH",
        "continent": "Asia",
        "name": "Philippines",
        "capital": "Manila",
    },
    {
        "timezones": ["Asia/Muscat"],
        "code": "OM",
        "continent": "Asia",
        "name": "Oman",
        "capital": "Muscat",
    },
    {
        "timezones": ["Asia/Nicosia"],
        "code": "CY",
        "continent": "Asia",
        "name": "Cyprus",
        "capital": "Nicosia",
    },
    {
        "timezones": ["Asia/Phnom_Penh"],
        "code": "KH",
        "continent": "Asia",
        "name": "Cambodia",
        "capital": "Phnom Penh",
    },
    {
        "timezones": ["Asia/Pyongyang"],
        "code": "KP",
        "continent": "Asia",
        "name": "North Korea",
        "capital": "Pyongyang",
    },
    {
        "timezones": ["Asia/Qatar"],
        "code": "QA",
        "continent": "Asia",
        "name": "Qatar",
        "capital": "Doha",
    },
    {
        "timezones": ["Asia/Rangoon"],
        "code": "MM",
        "continent": "Asia",
        "name": "Myanmar",
        "capital": "Naypyidaw",
    },
    {
        "timezones": ["Asia/Riyadh"],
        "code": "SA",
        "continent": "Asia",
        "name": "Saudi Arabia",
        "capital": "Riyadh",
    },
    {
        "timezones": ["Asia/Saigon"],
        "code": "VN",
        "continent": "Asia",
        "name": "Vietnam",
        "capital": "Hanoi",
    },
    {
        "timezones": ["Asia/Samarkand", "Asia/Tashkent"],
        "code": "UZ",
        "continent": "Asia",
        "name": "Uzbekistan",
        "capital": "Tashkent",
    },
    {
        "timezones": ["Asia/Seoul"],
        "code": "KR",
        "continent": "Asia",
        "name": "South Korea",
        "capital": "Seoul",
    },
    {
        "timezones": [
            "Asia/Shanghai",
            "Asia/Harbin",
            "Asia/Chongqing",
            "Asia/Urumqi",
            "Asia/Kashgar",
        ],
        "code": "CN",
        "continent": "Asia",
        "name": "China",
        "capital": "Beijing",
    },
    {
        "timezones": ["Asia/Singapore"],
        "code": "SG",
        "continent": "Asia",
        "name": "Singapore",
        "capital": "Singapore",
    },
    {
        "timezones": ["Asia/Taipei"],
        "code": "TW",
        "continent": "Asia",
        "name": "Taiwan",
        "capital": "Taipei",
    },
    {
        "timezones": ["Asia/Tbilisi"],
        "code": "GE",
        "continent": "Asia",
        "name": "Georgia",
        "capital": "Tbilisi",
    },
    {
        "timezones": ["Asia/Tehran"],
        "code": "IR",
        "continent": "Asia",
        "name": "Iran",
        "capital": "Tehran",
    },
    {
        "timezones": ["Asia/Thimphu"],
        "code": "BT",
        "continent": "Asia",
        "name": "Bhutan",
        "capital": "Thimphu",
    },
    {
        "timezones": ["Asia/Tokyo"],
        "code": "JP",
        "continent": "Asia",
        "name": "Japan",
        "capital": "Tokyo",
    },
    {
        "timezones": ["Asia/Ulaanbaatar", "Asia/Hovd", "Asia/Choibalsan"],
        "code": "MN",
        "continent": "Asia",
        "name": "Mongolia",
        "capital": "Ulaanbaatar",
    },
    {
        "timezones": ["Asia/Vientiane"],
        "code": "LA",
        "continent": "Asia",
        "name": "Laos",
        "capital": "Vientiane",
    },
    {
        "timezones": ["Asia/Yerevan"],
        "code": "AM",
        "continent": "Asia",
        "name": "Armenia",
        "capital": "Yerevan",
    },
    {
        "timezones": ["Atlantic/Cape_Verde"],
        "code": "CV",
        "continent": "Africa",
        "name": "Cape Verde",
        "capital": "Praia",
    },
    {
        "timezones": ["Atlantic/Reykjavik"],
        "code": "IS",
        "continent": "Europe",
        "name": "Iceland",
        "capital": "Reykjav\xc3\xadk",
    },
    {
        "timezones": [
            "Australia/Lord_Howe",
            "Australia/Hobart",
            "Australia/Currie",
            "Australia/Melbourne",
            "Australia/Sydney",
            "Australia/Broken_Hill",
            "Australia/Brisbane",
            "Australia/Lindeman",
            "Australia/Adelaide",
            "Australia/Darwin",
            "Australia/Perth",
        ],
        "code": "AU",
        "continent": "Oceania",
        "name": "Australia",
        "capital": "Canberra",
    },
    {
        "timezones": ["Europe/Amsterdam"],
        "code": "NL",
        "continent": "Europe",
        "name": "Netherlands",
        "capital": "Amsterdam",
    },
    {
        "timezones": ["Europe/Andorra"],
        "code": "AD",
        "continent": "Europe",
        "name": "Andorra",
        "capital": "Andorra la Vella",
    },
    {
        "timezones": ["Europe/Athens"],
        "code": "GR",
        "continent": "Europe",
        "name": "Greece",
        "capital": "Athens",
    },
    {
        "timezones": ["Europe/Belgrade"],
        "code": "RS",
        "continent": "Europe",
        "name": "Serbia",
        "capital": "Belgrade",
    },
    {
        "timezones": ["Europe/Berlin"],
        "code": "DE",
        "continent": "Europe",
        "name": "Germany",
        "capital": "Berlin",
    },
    {
        "timezones": ["Europe/Bratislava"],
        "code": "SK",
        "continent": "Europe",
        "name": "Slovakia",
        "capital": "Bratislava",
    },
    {
        "timezones": ["Europe/Brussels"],
        "code": "BE",
        "continent": "Europe",
        "name": "Belgium",
        "capital": "Brussels",
    },
    {
        "timezones": ["Europe/Bucharest"],
        "code": "RO",
        "continent": "Europe",
        "name": "Romania",
        "capital": "Bucharest",
    },
    {
        "timezones": ["Europe/Budapest"],
        "code": "HU",
        "continent": "Europe",
        "name": "Hungary",
        "capital": "Budapest",
    },
    {
        "timezones": ["Europe/Chisinau"],
        "code": "MD",
        "continent": "Europe",
        "name": "Moldova",
        "capital": "Chi\xc5\x9fin\xc4\x83u",
    },
    {
        "timezones": ["Europe/Copenhagen"],
        "code": "DK",
        "continent": "Europe",
        "name": "Denmark",
        "capital": "Copenhagen",
    },
    {
        "timezones": ["Europe/Dublin"],
        "code": "IE",
        "continent": "Europe",
        "name": "Republic of Ireland",
        "capital": "Dublin",
    },
    {
        "timezones": ["Europe/Helsinki"],
        "code": "FI",
        "continent": "Europe",
        "name": "Finland",
        "capital": "Helsinki",
    },
    {
        "timezones": ["Europe/Istanbul"],
        "code": "TR",
        "continent": "Asia",
        "name": "Turkey",
        "capital": "Ankara",
    },
    {
        "timezones": [
            "Europe/Kaliningrad",
            "Europe/Moscow",
            "Europe/Volgograd",
            "Europe/Samara",
            "Asia/Yekaterinburg",
            "Asia/Omsk",
            "Asia/Novosibirsk",
            "Asia/Krasnoyarsk",
            "Asia/Irkutsk",
            "Asia/Yakutsk",
            "Asia/Vladivostok",
            "Asia/Sakhalin",
            "Asia/Magadan",
            "Asia/Kamchatka",
            "Asia/Anadyr",
        ],
        "code": "RU",
        "continent": "Europe",
        "name": "Russia",
        "capital": "Moscow",
    },
    {
        "timezones": [
            "Europe/Kiev",
            "Europe/Uzhgorod",
            "Europe/Zaporozhye",
            "Europe/Simferopol",
        ],
        "code": "UA",
        "continent": "Europe",
        "name": "Ukraine",
        "capital": "Kiev",
    },
    {
        "timezones": ["Europe/Lisbon", "Atlantic/Madeira", "Atlantic/Azores"],
        "code": "PT",
        "continent": "Europe",
        "name": "Portugal",
        "capital": "Lisbon",
    },
    {
        "timezones": ["Europe/Ljubljana"],
        "code": "SI",
        "continent": "Europe",
        "name": "Slovenia",
        "capital": "Ljubljana",
    },
    {
        "timezones": ["Europe/London"],
        "code": "GB",
        "continent": "Europe",
        "name": "United Kingdom",
        "capital": "London",
    },
    {
        "timezones": ["Europe/Luxembourg"],
        "code": "LU",
        "continent": "Europe",
        "name": "Luxembourg",
        "capital": "Luxembourg City",
    },
    {
        "timezones": ["Europe/Madrid", "Africa/Ceuta", "Atlantic/Canary"],
        "code": "ES",
        "continent": "Europe",
        "name": "Spain",
        "capital": "Madrid",
    },
    {
        "timezones": ["Europe/Malta"],
        "code": "MT",
        "continent": "Europe",
        "name": "Malta",
        "capital": "Valletta",
    },
    {
        "timezones": ["Europe/Minsk"],
        "code": "BY",
        "continent": "Europe",
        "name": "Belarus",
        "capital": "Minsk",
    },
    {
        "timezones": ["Europe/Monaco"],
        "code": "MC",
        "continent": "Europe",
        "name": "Monaco",
        "capital": "Monaco",
    },
    {
        "timezones": ["Europe/Oslo"],
        "code": "NO",
        "continent": "Europe",
        "name": "Norway",
        "capital": "Oslo",
    },
    {
        "timezones": ["Europe/Paris"],
        "code": "FR",
        "continent": "Europe",
        "name": "France",
        "capital": "Paris",
    },
    {
        "timezones": ["Europe/Podgorica"],
        "code": "ME",
        "continent": "Europe",
        "name": "Montenegro",
        "capital": "Podgorica",
    },
    {
        "timezones": ["Europe/Prague"],
        "code": "CZ",
        "continent": "Europe",
        "name": "Czechia",
        "capital": "Prague",
    },
    {
        "timezones": ["Europe/Riga"],
        "code": "LV",
        "continent": "Europe",
        "name": "Latvia",
        "capital": "Riga",
    },
    {
        "timezones": ["Europe/Rome"],
        "code": "IT",
        "continent": "Europe",
        "name": "Italy",
        "capital": "Rome",
    },
    {
        "timezones": ["Europe/San_Marino"],
        "code": "SM",
        "continent": "Europe",
        "name": "San Marino",
        "capital": "San Marino",
    },
    {
        "timezones": ["Europe/Sarajevo"],
        "code": "BA",
        "continent": "Europe",
        "name": "Bosnia and Herzegovina",
        "capital": "Sarajevo",
    },
    {
        "timezones": ["Europe/Skopje"],
        "code": "MK",
        "continent": "Europe",
        "name": "Macedonia",
        "capital": "Skopje",
    },
    {
        "timezones": ["Europe/Sofia"],
        "code": "BG",
        "continent": "Europe",
        "name": "Bulgaria",
        "capital": "Sofia",
    },
    {
        "timezones": ["Europe/Stockholm"],
        "code": "SE",
        "continent": "Europe",
        "name": "Sweden",
        "capital": "Stockholm",
    },
    {
        "timezones": ["Europe/Tallinn"],
        "code": "EE",
        "continent": "Europe",
        "name": "Estonia",
        "capital": "Tallinn",
    },
    {
        "timezones": ["Europe/Tirane"],
        "code": "AL",
        "continent": "Europe",
        "name": "Albania",
        "capital": "Tirana",
    },
    {
        "timezones": ["Europe/Vaduz"],
        "code": "LI",
        "continent": "Europe",
        "name": "Liechtenstein",
        "capital": "Vaduz",
    },
    {
        "timezones": ["Europe/Vatican"],
        "code": "VA",
        "continent": "Europe",
        "name": "Vatican City",
        "capital": "Vatican City",
    },
    {
        "timezones": ["Europe/Vienna"],
        "code": "AT",
        "continent": "Europe",
        "name": "Austria",
        "capital": "Vienna",
    },
    {
        "timezones": ["Europe/Vilnius"],
        "code": "LT",
        "continent": "Europe",
        "name": "Lithuania",
        "capital": "Vilnius",
    },
    {
        "timezones": ["Europe/Warsaw"],
        "code": "PL",
        "continent": "Europe",
        "name": "Poland",
        "capital": "Warsaw",
    },
    {
        "timezones": ["Europe/Zagreb"],
        "code": "HR",
        "continent": "Europe",
        "name": "Croatia",
        "capital": "Zagreb",
    },
    {
        "timezones": ["Europe/Zurich"],
        "code": "CH",
        "continent": "Europe",
        "name": "Switzerland",
        "capital": "Bern",
    },
    {
        "timezones": ["Indian/Antananarivo"],
        "code": "MG",
        "continent": "Africa",
        "name": "Madagascar",
        "capital": "Antananarivo",
    },
    {
        "timezones": ["Indian/Comoro"],
        "code": "KM",
        "continent": "Africa",
        "name": "Comoros",
        "capital": "Moroni",
    },
    {
        "timezones": ["Indian/Mahe"],
        "code": "SC",
        "continent": "Africa",
        "name": "Seychelles",
        "capital": "Victoria",
    },
    {
        "timezones": ["Indian/Maldives"],
        "code": "MV",
        "continent": "Asia",
        "name": "Maldives",
        "capital": "Mal\xc3\xa9",
    },
    {
        "timezones": ["Indian/Mauritius"],
        "code": "MU",
        "continent": "Africa",
        "name": "Mauritius",
        "capital": "Port Louis",
    },
    {
        "timezones": ["Pacific/Apia"],
        "code": "WS",
        "continent": "Oceania",
        "name": "Samoa",
        "capital": "Apia",
    },
    {
        "timezones": ["Pacific/Auckland", "Pacific/Chatham"],
        "code": "NZ",
        "continent": "Oceania",
        "name": "New Zealand",
        "capital": "Wellington",
    },
    {
        "timezones": ["Pacific/Efate"],
        "code": "VU",
        "continent": "Oceania",
        "name": "Vanuatu",
        "capital": "Port Vila",
    },
    {
        "timezones": ["Pacific/Fiji"],
        "code": "FJ",
        "continent": "Oceania",
        "name": "Fiji",
        "capital": "Suva",
    },
    {
        "timezones": ["Pacific/Funafuti"],
        "code": "TV",
        "continent": "Oceania",
        "name": "Tuvalu",
        "capital": "Funafuti",
    },
    {
        "timezones": ["Pacific/Guadalcanal"],
        "code": "SB",
        "continent": "Oceania",
        "name": "Solomon Islands",
        "capital": "Honiara",
    },
    {
        "timezones": ["Pacific/Majuro", "Pacific/Kwajalein"],
        "code": "MH",
        "continent": "Oceania",
        "name": "Marshall Islands",
        "capital": "Majuro",
    },
    {
        "timezones": ["Pacific/Nauru"],
        "code": "NR",
        "continent": "Oceania",
        "name": "Nauru",
        "capital": "Yaren",
    },
    {
        "timezones": ["Pacific/Palau"],
        "code": "PW",
        "continent": "Oceania",
        "name": "Palau",
        "capital": "Ngerulmud",
    },
    {
        "timezones": ["Pacific/Port_Moresby"],
        "code": "PG",
        "continent": "Oceania",
        "name": "Papua New Guinea",
        "capital": "Port Moresby",
    },
    {
        "timezones": ["Pacific/Tarawa", "Pacific/Enderbury", "Pacific/Kiritimati"],
        "code": "KI",
        "continent": "Oceania",
        "name": "Kiribati",
        "capital": "Tarawa",
    },
    {
        "timezones": ["Pacific/Tongatapu"],
        "code": "TO",
        "continent": "Oceania",
        "name": "Tonga",
        "capital": "Nuku\xca\xbbalofa",
    },
    {
        "timezones": ["Pacific/Truk", "Pacific/Ponape", "Pacific/Kosrae"],
        "code": "FM",
        "continent": "Oceania",
        "name": "Federated States of Micronesia",
        "capital": "Palikir",
    },
]
